@@ -1,12 +1,12 @@
 """
 The framework for making database tests.
 """
+from __future__ import print_function
 
 import logging
 import os
-import re
 import sys
-from py.test import raises
+from py.test import raises, skip
 import sqlobject
 import sqlobject.conftest as conftest
 
@@ -29,7 +29,7 @@ and you can use it like::
 
     def test_featureX():
         if not supports('featureX'):
-            return
+            py.test.skip("Doesn't support featureX")
 """
 supportsMatrix = {
     '+exceptions': 'mysql postgres sqlite',
@@ -39,9 +39,10 @@ supportsMatrix = {
     '-blobData': 'mssql rdbhost',
     '-decimalColumn': 'mssql',
     '-emptyTable': 'mssql',
-    '-limitSelect' : 'mssql',
-    '+schema' : 'postgres',
-    }
+    '-limitSelect': 'mssql',
+    '+schema': 'postgres',
+    '+memorydb': 'sqlite',
+}
 
 
 def setupClass(soClasses, force=False):
@@ -65,22 +66,31 @@ def setupClass(soClasses, force=False):
         soClasses = [soClasses]
     connection = getConnection()
     for soClass in soClasses:
-        ## This would be an alternate way to register connections...
-        #try:
+        # This would be an alternate way to register connections:
+        # try:
         #    hub
-        #except NameError:
+        # except NameError:
         #    hub = sqlobject.dbconnection.ConnectionHub()
-        #soClass._connection = hub
-        #hub.threadConnection = connection
-        #hub.processConnection = connection
+        # soClass._connection = hub
+        # hub.threadConnection = connection
+        # hub.processConnection = connection
         soClass._connection = connection
     installOrClear(soClasses, force=force)
     return soClasses
 
+
+def speedupSQLiteConnection(connection):
+    connection.query("PRAGMA synchronous=OFF")
+    connection.query("PRAGMA count_changes=OFF")
+    connection.query("PRAGMA journal_mode=MEMORY")
+    connection.query("PRAGMA temp_store=MEMORY")
+
 installedDBFilename = os.path.join(getcwd(), 'dbs_data.tmp')
 
 installedDBTracker = sqlobject.connectionForURI(
     'sqlite:///' + installedDBFilename)
+speedupSQLiteConnection(installedDBTracker)
+
 
 def getConnection(**kw):
     name = getConnectionURI()
@@ -89,8 +99,11 @@ def getConnection(**kw):
         conn.debug = True
     if conftest.option.show_sql_output:
         conn.debugOutput = True
+    if conn.dbName == 'sqlite':
+        speedupSQLiteConnection(conn)
     return conn
 
+
 def getConnectionURI():
     name = conftest.option.Database
     if name in conftest.connectionShortcuts:
@@ -99,10 +112,9 @@ def getConnectionURI():
 
 try:
     connection = getConnection()
-except Exception, e:
+except Exception as e:
     # At least this module should be importable...
-    print >> sys.stderr, (
-        "Could not open database: %s" % e)
+    print("Could not open database: %s" % e, file=sys.stderr)
 
 
 class InstalledTestDatabase(sqlobject.SQLObject):
@@ -206,6 +218,7 @@ class InstalledTestDatabase(sqlobject.SQLObject):
 
 installOrClear = InstalledTestDatabase.installOrClear
 
+
 class Dummy(object):
 
     """
@@ -216,6 +229,7 @@ class Dummy(object):
         for name, value in kw.items():
             setattr(self, name, value)
 
+
 def inserts(cls, data, schema=None):
     """
     Creates a bunch of rows.
@@ -247,6 +261,7 @@ def inserts(cls, data, schema=None):
         results.append(cls(**args))
     return results
 
+
 def supports(feature):
     dbName = connection.dbName
     support = supportsMatrix.get('+' + feature, None)
@@ -263,10 +278,11 @@ def supports(feature):
         "The supportMatrix does not list this feature: %r"
         % feature)
 
-    
+
 # To avoid name clashes:
 _inserts = inserts
 
+
 def setSQLiteConnectionFactory(TableClass, factory):
     from sqlobject.sqlite.sqliteconnection import SQLiteConnection
     conn = TableClass._connection
@@ -277,12 +293,15 @@ def setSQLiteConnectionFactory(TableClass, factory):
         debugThreading=conn.debugThreading, registry=conn.registry,
         factory=factory
     )
+    speedupSQLiteConnection(TableClass._connection)
     installOrClear([TableClass])
 
+
 def deprecated_module():
     sqlobject.main.warnings_level = None
     sqlobject.main.exception_level = None
 
+
 def setup_module(mod):
     # modules with '_old' test backward compatible methods, so they
     # don't get warnings or errors.
@@ -296,10 +315,12 @@ def setup_module(mod):
         sqlobject.main.warnings_level = None
         sqlobject.main.exception_level = 0
 
+
 def teardown_module(mod=None):
     sqlobject.main.warnings_level = None
     sqlobject.main.exception_level = 0
 
+
 def setupLogging():
     fmt = '[%(asctime)s] %(name)s %(levelname)s: %(message)s'
     formatter = logging.Formatter(fmt)
@@ -309,6 +330,24 @@ def setupLogging():
     logger = logging.getLogger()
     logger.addHandler(hdlr)
 
-__all__ = ['getConnection', 'getConnectionURI', 'setupClass', 'Dummy', 'raises',
-           'inserts', 'supports', 'deprecated_module',
-           'setup_module', 'teardown_module', 'setupLogging']
+
+def setupCyclicClasses(*classes):
+    if not supports('dropTableCascade'):
+        skip("dropTableCascade isn't supported")
+    conn = getConnection()
+    for soClass in classes:
+        soClass.setConnection(conn)
+        soClass.dropTable(ifExists=True, cascade=True)
+
+    constraints = []
+    for soClass in classes:
+        constraints += soClass.createTable(ifNotExists=True,
+                                           applyConstraints=False)
+    for constraint in constraints:
+        conn.query(constraint)
+
+
+__all__ = ['Dummy', 'deprecated_module', 'getConnection', 'getConnectionURI',
+           'inserts', 'raises', 'setupClass', 'setupCyclicClasses',
+           'setupLogging', 'setup_module', 'supports', 'teardown_module',
+           ]
