@@ -1,11 +1,13 @@
 from sqlobject import *
 from sqlobject.tests.dbtest import *
 
+
 class TestComparison(SQLObject):
     pass
 
+
 def test_eq():
-    setupClass(TestComparison)
+    setupClass(TestComparison, force=True)
     t1 = TestComparison()
     t2 = TestComparison()
 
@@ -19,4 +21,4 @@ def test_eq():
     assert t2 is not t4
     assert t1 == t3
     assert t2 == t4
-    assert t1 <> t2
+    assert t1 != t2
