@@ -1,14 +1,23 @@
+import py.test
 from sqlobject import *
 from sqlobject.tests.dbtest import *
 
+
 ########################################
-## Slicing tests
+# Slicing tests
 ########################################
 
+
+def listrange(*args):
+    """Always return a list, for py3k compatibility"""
+    return list(range(*args))
+
+
 class Counter(SQLObject):
 
     number = IntCol(notNull=True)
 
+
 class TestSlice:
 
     def setup_method(self, meth):
@@ -18,33 +27,33 @@ class TestSlice:
 
     def counterEqual(self, counters, value):
         if not supports('limitSelect'):
-            return
+            py.test.skip("limitSelect isn't supported")
         assert [c.number for c in counters] == value
 
     def test_slice(self):
         self.counterEqual(
-            Counter.select(None, orderBy='number'), range(100))
+            Counter.select(None, orderBy='number'), listrange(100))
 
         self.counterEqual(
             Counter.select(None, orderBy='number')[10:20],
-            range(10, 20))
+            listrange(10, 20))
 
         self.counterEqual(
             Counter.select(None, orderBy='number')[20:30][:5],
-            range(20, 25))
+            listrange(20, 25))
 
         self.counterEqual(
             Counter.select(None, orderBy='number')[20:30][1:5],
-            range(21, 25))
+            listrange(21, 25))
 
         self.counterEqual(
             Counter.select(None, orderBy='number')[:-10],
-            range(0, 90))
+            listrange(0, 90))
 
         self.counterEqual(
             Counter.select(None, orderBy='number', reversed=True),
-            range(99, -1, -1))
+            listrange(99, -1, -1))
 
         self.counterEqual(
             Counter.select(None, orderBy='-number'),
-            range(99, -1, -1))
+            listrange(99, -1, -1))
