@@ -1,29 +1,41 @@
 from sqlobject import *
+from sqlobject.compat import PY2
 from sqlobject.sqlbuilder import *
 from sqlobject.tests.dbtest import *
 
+
 class TestSQLBuilder(SQLObject):
     name = StringCol()
     value = IntCol()
 
+
 def test_Select():
     setupClass(TestSQLBuilder)
 
-    select1 = Select([const.id, func.MAX(const.salary)], staticTables=['employees'])
+    select1 = Select([const.id, func.MAX(const.salary)],
+                     staticTables=['employees'])
     assert sqlrepr(select1) == 'SELECT id, MAX(salary) FROM employees'
 
     select2 = Select([TestSQLBuilder.q.name, TestSQLBuilder.q.value])
-    assert sqlrepr(select2) == 'SELECT test_sql_builder.name, test_sql_builder.value FROM test_sql_builder'
+    assert sqlrepr(select2) == \
+        'SELECT test_sql_builder.name, test_sql_builder.value ' \
+        'FROM test_sql_builder'
 
     union = Union(select1, select2)
-    assert sqlrepr(union) == 'SELECT id, MAX(salary) FROM employees UNION SELECT test_sql_builder.name, test_sql_builder.value FROM test_sql_builder'
+    assert sqlrepr(union) == \
+        'SELECT id, MAX(salary) FROM employees ' \
+        'UNION SELECT test_sql_builder.name, test_sql_builder.value ' \
+        'FROM test_sql_builder'
 
     union = Union(TestSQLBuilder.select().queryForSelect())
-    assert sqlrepr(union) == 'SELECT test_sql_builder.id, test_sql_builder.name, test_sql_builder.value FROM test_sql_builder WHERE 1 = 1'
+    assert sqlrepr(union) == \
+        'SELECT test_sql_builder.id, test_sql_builder.name, ' \
+        'test_sql_builder.value FROM test_sql_builder WHERE 1 = 1'
+
 
 def test_empty_AND():
-    assert AND() == None
-    assert AND(True) == True
+    assert AND() is None
+    assert AND(True) is True
 
     # sqlrepr() is needed because AND() returns an SQLExpression that overrides
     # comparison. The following
@@ -34,6 +46,7 @@ def test_empty_AND():
         sqlrepr(SQLOp("AND", 1, SQLOp("AND", 2, '3')), "sqlite") == \
         "((1) AND ((2) AND ('3')))"
 
+
 def test_modulo():
     setupClass(TestSQLBuilder)
     assert sqlrepr(TestSQLBuilder.q.value % 2 == 0, 'mysql') == \
@@ -41,14 +54,15 @@ def test_modulo():
     assert sqlrepr(TestSQLBuilder.q.value % 2 == 0, 'sqlite') == \
         "(((test_sql_builder.value) % (2)) = (0))"
 
+
 def test_str_or_sqlrepr():
     select = Select(['id', 'name'], staticTables=['employees'],
-        where='value>0', orderBy='id')
+                    where='value>0', orderBy='id')
     assert sqlrepr(select, 'sqlite') == \
         'SELECT id, name FROM employees WHERE value>0 ORDER BY id'
 
     select = Select(['id', 'name'], staticTables=['employees'],
-        where='value>0', orderBy='id', lazyColumns=True)
+                    where='value>0', orderBy='id', lazyColumns=True)
     assert sqlrepr(select, 'sqlite') == \
         'SELECT id FROM employees WHERE value>0 ORDER BY id'
 
@@ -74,6 +88,7 @@ def test_str_or_sqlrepr():
     assert sqlrepr(delete, 'sqlite') == \
         "DELETE FROM employees"
 
+
 def test_CONCAT():
     setupClass(TestSQLBuilder)
     TestSQLBuilder(name='test', value=42)
@@ -90,4 +105,6 @@ def test_CONCAT():
     connection = getConnection()
     rows = connection.queryAll(connection.sqlrepr(select))
     result = rows[0][0]
+    if not PY2 and not isinstance(result, str):
+        result = result.decode('ascii')
     assert result == "test-suffix"
