@@ -8,43 +8,55 @@ class MyClass(SQLObject):
     name = StringCol()
     versions = Versioning()
 
+
 class Base(InheritableSQLObject):
     name = StringCol()
     value = IntCol(default=0)
     versions = Versioning()
 
+
 class Child(Base):
     toy = StringCol()
 
+
 class Government(InheritableSQLObject):
     name = StringCol()
 
+
 class Monarchy(Government):
     monarch = StringCol()
     versions = Versioning()
 
+
 class VChild(Base):
     weapon = StringCol()
     versions = Versioning()
 
+
 class HasForeign(SQLObject):
     foreign = ForeignKey("Base")
     versions = Versioning()
 
+
 def _set_extra():
     return "read all about it"
 
+
 class Extra(SQLObject):
     name = StringCol()
-    versions = Versioning(extraCols={'extra' : StringCol(default=_set_extra())})
+    versions = Versioning(
+        extraCols={'extra': StringCol(default=_set_extra())})
+
 
 class HasAltId(SQLObject):
     name = StringCol()
     altid = IntCol(alternateID=True)
     versions = Versioning()
 
+
 def setup():
-    classes = [MyClass, Base, Child, Government, Monarchy, VChild, Extra, HasAltId]
+    classes = [MyClass, Base, Child, Government,
+               Monarchy, VChild, Extra, HasAltId]
     if hasattr(HasForeign, "_connection"):
         classes.insert(0, HasForeign)
     else:
@@ -59,8 +71,9 @@ def setup():
             for version in cls.versions.versionClass.select():
                 version.destroySelf()
 
+
 def test_versioning():
-    #the simple case
+    # the simple case
     setup()
     mc = MyClass(name='fleem')
     mc.set(name='morx')
@@ -69,10 +82,11 @@ def test_versioning():
 
     assert len(list(MyClass.select())) == 1
 
+
 def test_inheritable_versioning():
     setup()
 
-    #base versioned, child unversioned
+    # base versioned, child unversioned
     base = Base(name='fleem')
     base.set(name='morx')
     assert len(list(base.versions)) == 1
@@ -83,8 +97,7 @@ def test_inheritable_versioning():
     child.set(name='teenager', toy='guitar')
     assert len(list(child.versions)) == 0
 
-
-    #child versioned, base unversioned
+    # child versioned, base unversioned
     government = Government(name='canada')
     assert not hasattr(government, 'versions')
 
@@ -95,15 +108,17 @@ def test_inheritable_versioning():
     assert monarchy.versions[0].name == "UK"
     assert len(list(Monarchy.select())) == 1
 
-    #both parent and child versioned
+    # both parent and child versioned
     num_base_versions = len(list(base.versions))
     vchild = VChild(name='kid', weapon='slingshot')
     vchild.set(name='toon', weapon='dynamite')
     assert len(list(base.versions)) == num_base_versions
     assert len(list(vchild.versions)) == 1
-    vchild.name = "newname" #test setting using setattr directly rather than .set
+    # test setting using setattr directly rather than .set
+    vchild.name = "newname"
     assert len(list(vchild.versions)) == 2
 
+
 def test_restore():
     setup()
     base = Base(name='fleem')
@@ -125,6 +140,7 @@ def test_restore():
     extra.versions[0].restore()
     assert extra.name == "fleem"
 
+
 def test_next():
     setup()
     base = Base(name='first', value=1)
@@ -134,6 +150,7 @@ def test_next():
     assert version.nextVersion() == base.versions[1]
     assert version.nextVersion().nextVersion() == base
 
+
 def test_get_changed():
     setup()
     base = Base(name='first', value=1)
@@ -142,22 +159,25 @@ def test_get_changed():
     assert base.versions[0].getChangedFields() == ['Name']
     assert sorted(base.versions[1].getChangedFields()) == ['Name', 'Value']
 
+
 def test_foreign_keys():
     setup()
     base1 = Base(name='first', value=1)
     base2 = Base(name='first', value=1)
-    has_foreign = HasForeign(foreign = base1)
+    has_foreign = HasForeign(foreign=base1)
     has_foreign.foreign = base2
     assert has_foreign.versions[0].foreign == base1
 
+
 def test_extra():
     setup()
     extra = Extra(name='title')
     extra.name = 'new'
-    assert extra.versions[0].extra == 'read all about it'    
+    assert extra.versions[0].extra == 'read all about it'
     assert sorted(extra.versions[0].getChangedFields()) == ['Name']
 
+
 def test_altid():
     setup()
-    extra = HasAltId(name="fleem", altid=5) 
+    extra = HasAltId(name="fleem", altid=5)
     extra.name = "morx"
